==> libggi_1.99.2.0b2.1.orig.tar.gz: libggi-2.0b2.1/default/linear_16/visual.c <==
/* $Id: visual.c,v 1.21 1999/03/20 01:04:45 marcus Exp $
******************************************************************************

   Graphics library for GGI.

   Copyright (C) 1995 Andreas Beck     [becka@ggi-project.org]
   Copyright (C) 1997 Jason McMullan   [jmcc@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "lin16lib.h"


int GGIdlinit(ggi_visual *vis, const char *args, void *argptr)
{
	/* Frame handling
	 */

	vis->opdraw->setreadframe  = _ggi_default_setreadframe;
	vis->opdraw->setwriteframe = _ggi_default_setwriteframe;
	
	/* Generic drawing
	 */
	if (vis->needidleaccel) {
		vis->opdraw->drawpixel_nc	= GGI_lin16_drawpixel_nca;
		vis->opdraw->drawpixel		= GGI_lin16_drawpixela;
		vis->opdraw->putpixel_nc	= GGI_lin16_putpixel_nca;
		vis->opdraw->putpixel		= GGI_lin16_putpixela;
		vis->opdraw->getpixel		= GGI_lin16_getpixela;
	} else {
		vis->opdraw->drawpixel_nc	= GGI_lin16_drawpixel_nc;
		vis->opdraw->drawpixel		= GGI_lin16_drawpixel;
		vis->opdraw->putpixel_nc	= GGI_lin16_putpixel_nc;
		vis->opdraw->putpixel		= GGI_lin16_putpixel;
		vis->opdraw->getpixel		= GGI_lin16_getpixel;
	}

	vis->opdraw->drawhline		= GGI_lin16_drawhline;
	vis->opdraw->drawhline_nc	= GGI_lin16_drawhline_nc;
	vis->opdraw->puthline		= GGI_lin16_puthline;
	vis->opdraw->gethline		= GGI_lin16_gethline;

	vis->opdraw->drawvline		= GGI_lin16_drawvline;
	vis->opdraw->drawvline_nc	= GGI_lin16_drawvline_nc;
	vis->opdraw->putvline		= GGI_lin16_putvline;
	vis->opdraw->getvline		= GGI_lin16_getvline;

	vis->opdraw->drawline		= GGI_lin16_drawline;

	vis->opdraw->drawbox		= GGI_lin16_drawbox;
	vis->opdraw->putbox		= GGI_lin16_putbox;
	vis->opdraw->copybox		= GGI_lin16_copybox;
	vis->opdraw->crossblit		= GGI_lin16_crossblit;

	return GGI_DL_OPDRAW;
}

int GGIdlcleanup(ggi_visual *vis)
{
	return 0;
}
		
#include <ggi/internal/ggidlinit.h>

==> libggi-2.0b1.tar.gz: libggi-2.0b1/default/linear_16/visual.c <==
/* $Id: visual.c,v 1.17 1998/12/09 04:27:27 marcus Exp $
******************************************************************************

   Graphics library for GGI.

   Copyright (C) 1995 Andreas Beck     [becka@ggi-project.org]
   Copyright (C) 1997 Jason McMullan   [jmcc@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <ggi/internal/ggi-dl.h>

int GGIdlinit(ggi_visual *visual,const char *version,void *argptr)
{
	/* Frame handling
	 */

	visual->opdraw->setreadframe = _ggi_default_setreadframe;
	visual->opdraw->setwriteframe = _ggi_default_setwriteframe;
	
	/* Generic drawing
	 */
	visual->opdraw->drawpixel_nc=GGIdrawpixel_nc;
	visual->opdraw->drawpixel=GGIdrawpixel;
	visual->opdraw->putpixel_nc=GGIputpixel_nc;
	visual->opdraw->putpixel=GGIputpixel;
	visual->opdraw->getpixel=GGIgetpixel;

	visual->opdraw->drawhline=GGIdrawhline;
	visual->opdraw->drawhline_nc=GGIdrawhline_nc;
	visual->opdraw->puthline=GGIputhline;
	visual->opdraw->gethline=GGIgethline;

	visual->opdraw->drawvline=GGIdrawvline;
	visual->opdraw->drawvline_nc=GGIdrawvline_nc;
	visual->opdraw->putvline=GGIputvline;
	visual->opdraw->getvline=GGIgetvline;

	visual->opdraw->drawline=GGIdrawline;
	visual->opdraw->copybox=GGIcopybox;

	return GGI_DL_OPDRAW;
}

int GGIdlcleanup(ggi_visual *visual)
{
	return 0;
}
		
#include <ggi/internal/ggidlinit.h>
